'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (babel) {
  const { types: t } = babel;
  let macroBuilder;
  let options;

  return {
    name: "babel-feature-flags-and-debug-macros",
    visitor: {

      Program: {
        enter(path, state) {
          options = (0, _normalizeOptions.normalizeOptions)(state.opts);
          macroBuilder = new _macros2.default(t, options);
        },

        exit(path) {
          if (macroBuilder.importedDebugTools) {
            macroBuilder.expand(path);
          }
        }
      },

      ImportDeclaration(path, state) {
        let importPath = path.node.source.value;

        let {
          featureImportSpecifiers,
          debugTools: { debugToolsImport },
          envFlags: { flags: { DEBUG } }
        } = options;

        let isFeaturesImport = featureImportSpecifiers.includes(importPath);

        if (isFeaturesImport && !DEBUG) {
          macroBuilder.inlineFeatureFlags(path);
        } else if (debugToolsImport && debugToolsImport === importPath) {
          macroBuilder.collectDebugToolsSpecifiers(path.node.specifiers);
        }
      },

      ExpressionStatement(path) {
        macroBuilder.build(path);
      }
    }
  };
};

var _macros = require('./lib/utils/macros');

var _macros2 = _interopRequireDefault(_macros);

var _fs = require('fs');

var _path = require('path');

var _normalizeOptions = require('./lib/utils/normalize-options');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }